/*
 * Copyright (C) 2025 JRNitre nichinichisou67@outlook.com
 * @file 	i2c.h
 * @brief	基于 STM32 标准库的软件 i2c 驱动库
 * 
 * @author 	JRNitre
 * @email	nichinichisou67@outlook.com
 * @version	v1.0
 * @date	2025-03-31
 * @license	LGPL 3.0
*/

//TODO 重构代码，对核心功能进行封装，方便移植
//TODO 调整延时函数，使得可以灵活适应不同主频和延时方式

#ifndef __I2C_H
#define __I2C_H

/* INCLUDE FILE */
// STM32F401CCU6
#include "stm32f4xx.h"

/* I2C 引脚&时钟配置 [在这里修改引脚 标准库下可以直接使用函数进行 I2C 通讯] */
#define I2C_SCL_PIN					GPIO_Pin_3
#define I2C_SDA_PIN					GPIO_Pin_4
#define I2C_GROUP					GPIOB
#define I2C_RCC_CLOCK_CMD			RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOB, ENABLE);

/* 这个参数用于配置延时时间， 84Mhz 下这里可以实现 5us 的延时 */
// TODO 这里后续会提供计算公式，也许会修改工作逻辑让代码更加通用
static uint8_t i2cSpeedDelay = 5;

/* FUNCTION */
void i2cInit(void);

void i2cSignal_Start(void);
void i2cSignal_Stop(void);

void i2cSend_Byte(uint8_t byte);
uint8_t i2cReceive_Byte(void);

void i2cSend_ACK(uint8_t ackBit);
uint8_t i2cReceive_ACK(void);

// 这个延时函数默认是不提供的，可以自行取消注释在其它位置调用
//void i2cDelay_us(uint32_t us);

#endif
